import React from 'react';

import {OrganizationHealth} from 'app/views/organizationHealth';
import {mount} from 'enzyme';
import {setActiveOrganization} from 'app/actionCreators/organizations';

import {selectByLabel} from '../../../helpers/select';

describe('OrganizationHealth', function() {
  let wrapper;
  const router = TestStubs.router({
    location: {
      pathname: '/organizations/org-slug/health/',
      query: {},
    },
  });
  const project = TestStubs.Project({isMember: true});
  const organization = TestStubs.Organization({
    features: ['health'],
    projects: [project],
  });

  beforeAll(async function() {
    MockApiClient.addMockResponse({
      url: `/organizations/${organization.slug}/environments/`,
      body: TestStubs.Environments(),
    });

    setActiveOrganization(organization);
    await tick();

    wrapper = mount(
      <OrganizationHealth router={router} organization={organization}>
        <div />
      </OrganizationHealth>,
      TestStubs.routerContext([
        {
          organization,
        },
      ])
    );
  });

  it('renders', function() {
    expect(wrapper.find('HealthWrapper')).toHaveLength(1);
  });

  it('updates router when changing environments', async function() {
    wrapper.find('MultipleEnvironmentSelector .dropdown-actor').simulate('click');
    await tick();
    wrapper.update();

    selectByLabel(wrapper, 'production', {control: true, name: 'environments'});
    expect(router.push).toHaveBeenCalledWith({
      pathname: '/organizations/org-slug/health/',
      query: {
        environments: ['production'],
      },
    });
    selectByLabel(wrapper, 'staging', {control: true, name: 'environments'});
    expect(router.push).toHaveBeenCalledWith({
      pathname: '/organizations/org-slug/health/',
      query: {
        environments: ['production', 'staging'],
      },
    });
  });

  it('updates component state when router is updated', async function() {
    wrapper = mount(
      <OrganizationHealth router={router} organization={organization}>
        <div />
      </OrganizationHealth>,
      TestStubs.routerContext([
        {
          organization,
        },
      ])
    );
    expect(wrapper.state('environments')).toEqual([]);

    wrapper.setProps({
      router: {
        location: {
          pathname: '/organizations/org-slug/health/',
          query: {
            environments: ['production'],
          },
        },
      },
    });
    expect(wrapper.state('environments')).toEqual(['production']);

    wrapper.setProps({
      router: {
        location: {
          pathname: '/organizations/org-slug/health/',
          query: {
            environments: ['production', 'staging'],
          },
        },
      },
    });
    expect(wrapper.state('environments')).toEqual(['production', 'staging']);
  });
});
